@@ -1,17 +1,16 @@
-from ..authentication.types import AuthenticationClientOptions
 from .. import __version__
 import requests
 
 
 class RestClient(object):
     def __init__(self, options):
-        # type:(AuthenticationClientOptions) -> RestClient
         self.options = options
 
     def request(self, method, url, token=None, **kwargs):
         headers = {
-            'x-authing-sdk-version': 'py3:%s' % __version__,
+            'x-authing-sdk-version': 'python:%s' % __version__,
             'x-authing-userpool-id': self.options.user_pool_id,
+            'x-authing-app-id': self.options.app_id,
             'x-authing-request-from': 'sdk',
         }
         if token:
